<?php

namespace App\Command;

use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Style\SymfonyStyle;
use App\Entity\EavAttribute;
use App\Entity\WebsiteEntity;
use Doctrine\Common\Persistence\ObjectManager;
use App\Service\WebsiteManager;

class SampleDataCommand extends Command
{
    protected static $defaultName = 'app:sample-data';
    private $entityManager;

    protected function configure()
    {
        $this
            ->setDescription('Adding sample data.')
        ;
    }

    public function __construct(ObjectManager $entityManager, WebsiteManager $websiteManager)
    {
        $this->entityManager = $entityManager;
        $this->websiteManager = $websiteManager;

        parent::__construct();
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        $io = new SymfonyStyle($input, $output);

        $ktam = 30;
        $kattributes = 3;

        for ($i = 1; $i <= $kattributes; ++$i) {
            $newEavAttribute = new EavAttribute();
            $newEavAttribute->setCode('code'.$i.'string');
            $newEavAttribute->setDescription('Description '.$i.' string.');
            $newEavAttribute->setType('string');
            $this->entityManager->persist($newEavAttribute);

            $newEavAttribute = new EavAttribute();
            $newEavAttribute->setCode('code'.$i.'text');
            $newEavAttribute->setDescription('Description '.$i.' text.');
            $newEavAttribute->setType('text');
            $this->entityManager->persist($newEavAttribute);

            $newEavAttribute = new EavAttribute();
            $newEavAttribute->setCode('code'.$i.'boolean');
            $newEavAttribute->setDescription('Description '.$i.' boolean.');
            $newEavAttribute->setType('boolean');
            $this->entityManager->persist($newEavAttribute);

            $newEavAttribute = new EavAttribute();
            $newEavAttribute->setCode('code'.$i.'integer');
            $newEavAttribute->setDescription('Description '.$i.' integer.');
            $newEavAttribute->setType('integer');
            $this->entityManager->persist($newEavAttribute);

            $newEavAttribute = new EavAttribute();
            $newEavAttribute->setCode('code'.$i.'float');
            $newEavAttribute->setDescription('Description '.$i.' float.');
            $newEavAttribute->setType('float');
            $this->entityManager->persist($newEavAttribute);

            $newEavAttribute = new EavAttribute();
            $newEavAttribute->setCode('code'.$i.'datetime');
            $newEavAttribute->setDescription('Description '.$i.' datetime.');
            $newEavAttribute->setType('datetime');
            $this->entityManager->persist($newEavAttribute);
        }
        $this->entityManager->flush();

        for ($i = 1; $i <= $ktam; ++$i) {
            $newWebsite = new WebsiteEntity();
            $newWebsite->setDomain('www.website'.$i.'.com');
            $newWebsite->setHttps(true);

            // First try..
            for ($j = 1; $j <= $kattributes; ++$j) {
                $this->websiteManager->setEavValue($newWebsite, 'code'.$j.'string', 'string'.$i.$j);
                $this->websiteManager->setEavValue($newWebsite, 'code'.$j.'text', 'text'.$i.$j);
                $this->websiteManager->setEavValue($newWebsite, 'code'.$j.'boolean', true);
                $this->websiteManager->setEavValue($newWebsite, 'code'.$j.'integer', $i);
                $this->websiteManager->setEavValue($newWebsite, 'code'.$j.'float', $i);
                $this->websiteManager->setEavValue($newWebsite, 'code'.$j.'datetime', new \DateTime());
            }

            $this->entityManager->persist($newWebsite);
            $this->entityManager->flush();

            // Second try to check if attr is overwriten or not..
            for ($j = 1; $j <= $kattributes; ++$j) {
                $this->websiteManager->setEavValue($newWebsite, 'code'.$j.'string', 'string'.$i.$j);
                $this->websiteManager->setEavValue($newWebsite, 'code'.$j.'text', 'text'.$i.$j);
                $this->websiteManager->setEavValue($newWebsite, 'code'.$j.'boolean', true);
                $this->websiteManager->setEavValue($newWebsite, 'code'.$j.'integer', $i);
                $this->websiteManager->setEavValue($newWebsite, 'code'.$j.'float', $i);
                $this->websiteManager->setEavValue($newWebsite, 'code'.$j.'datetime', new \DateTime());
            }

            $this->entityManager->persist($newWebsite);
            $this->entityManager->flush();
        }

        $io->success('Sample data added!');

        return 0;
    }
}
