<?php

namespace App\Controller;

use App\Entity\EavAttribute;
use App\Form\EavAttributeType;
use App\Repository\EavAttributeRepository;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

/**
 * @Route("/eav/attribute")
 */
class EavAttributeController extends AbstractController
{
    /**
     * @Route("/", name="eav_attribute_index", methods={"GET"})
     */
    public function index(EavAttributeRepository $eavAttributeRepository): Response
    {
        return $this->render('eav_attribute/index.html.twig', [
            'eav_attributes' => $eavAttributeRepository->findAll(),
        ]);
    }

    /**
     * @Route("/new", name="eav_attribute_new", methods={"GET","POST"})
     */
    public function new(Request $request): Response
    {
        $eavAttribute = new EavAttribute();
        $form = $this->createForm(EavAttributeType::class, $eavAttribute);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $entityManager = $this->getDoctrine()->getManager();
            $entityManager->persist($eavAttribute);
            $entityManager->flush();

            return $this->redirectToRoute('eav_attribute_index');
        }

        return $this->render('eav_attribute/new.html.twig', [
            'eav_attribute' => $eavAttribute,
            'form' => $form->createView(),
        ]);
    }

    /**
     * @Route("/{id}", name="eav_attribute_show", methods={"GET"})
     */
    public function show(EavAttribute $eavAttribute): Response
    {
        return $this->render('eav_attribute/show.html.twig', [
            'eav_attribute' => $eavAttribute,
        ]);
    }

    /**
     * @Route("/{id}/edit", name="eav_attribute_edit", methods={"GET","POST"})
     */
    public function edit(Request $request, EavAttribute $eavAttribute): Response
    {
        $form = $this->createForm(EavAttributeType::class, $eavAttribute);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $this->getDoctrine()->getManager()->flush();

            return $this->redirectToRoute('eav_attribute_index');
        }

        return $this->render('eav_attribute/edit.html.twig', [
            'eav_attribute' => $eavAttribute,
            'form' => $form->createView(),
        ]);
    }

    /**
     * @Route("/{id}", name="eav_attribute_delete", methods={"DELETE"})
     */
    public function delete(Request $request, EavAttribute $eavAttribute): Response
    {
        if ($this->isCsrfTokenValid('delete'.$eavAttribute->getId(), $request->request->get('_token'))) {
            $entityManager = $this->getDoctrine()->getManager();
            $entityManager->remove($eavAttribute);
            $entityManager->flush();
        }

        return $this->redirectToRoute('eav_attribute_index');
    }
}
