<?php

namespace App\Controller;

use App\Entity\WebsiteEntity;
use App\Form\WebsiteEntityType;
use App\Repository\WebsiteEntityRepository;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use App\Service\WebsiteManager;

/**
 * @Route("/website/entity")
 */
class WebsiteEntityController extends AbstractController
{
    /**
     * @Route("/", name="website_entity_index", methods={"GET"})
     */
    public function index(WebsiteEntityRepository $websiteEntityRepository): Response
    {
        return $this->render('website_entity/index.html.twig', [
            'website_entities' => $websiteEntityRepository->findAll(),
        ]);
    }

    /**
     * @Route("/new", name="website_entity_new", methods={"GET","POST"})
     */
    public function new(Request $request): Response
    {
        $websiteEntity = new WebsiteEntity();
        $form = $this->createForm(WebsiteEntityType::class, $websiteEntity);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $entityManager = $this->getDoctrine()->getManager();
            $entityManager->persist($websiteEntity);
            $entityManager->flush();

            return $this->redirectToRoute('website_entity_index');
        }

        return $this->render('website_entity/new.html.twig', [
            'website_entity' => $websiteEntity,
            'form' => $form->createView(),
        ]);
    }

    /**
     * @Route("/{id}", name="website_entity_show", methods={"GET"})
     */
    public function show(WebsiteEntity $websiteEntity): Response
    {
        return $this->render('website_entity/show.html.twig', [
            'website_entity' => $websiteEntity,
        ]);
    }

    /**
     * @Route("/{id}/edit", name="website_entity_edit", methods={"GET","POST"})
     */
    public function edit(Request $request, WebsiteEntity $websiteEntity, WebsiteManager $websiteManager): Response
    {
        $form = $this->createForm(WebsiteEntityType::class, $websiteEntity);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $data = $form->getData();
            $formParameters = $request->request->all();
            foreach ($formParameters as $entities) {
                foreach ($entities as $key => $value) {
                    //var_dump($value);
                    if ('domain' != $key and 'https' != $key) {
                        var_dump('Saving '.$key.'..');
                        $websiteManager->setEavValue($websiteEntity, $key, $value);
                    }
                }
            }

            $this->getDoctrine()->getManager()->flush();

            //exit;

            return $this->redirectToRoute('website_entity_edit', ['id' => $websiteEntity->getId()]);
        }

        return $this->render('website_entity/edit.html.twig', [
            'website_entity' => $websiteEntity,
            'form' => $form->createView(),
        ]);
    }

    /**
     * @Route("/{id}", name="website_entity_delete", methods={"DELETE"})
     */
    public function delete(Request $request, WebsiteEntity $websiteEntity): Response
    {
        if ($this->isCsrfTokenValid('delete'.$websiteEntity->getId(), $request->request->get('_token'))) {
            $entityManager = $this->getDoctrine()->getManager();
            $entityManager->remove($websiteEntity);
            $entityManager->flush();
        }

        return $this->redirectToRoute('website_entity_index');
    }
}
