<?php

namespace App\Entity;

use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;
use Symfony\Bridge\Doctrine\Validator\Constraints\UniqueEntity;

/**
 * @ORM\Entity(repositoryClass="App\Repository\EavAttributeRepository")
 * @UniqueEntity("code")
 */
class EavAttribute
{
    /**
     * @ORM\Id()
     * @ORM\GeneratedValue()
     * @ORM\Column(type="integer")
     */
    private $id;

    /**
     * @ORM\Column(type="string", length=255)
     */
    private $description;

    /**
     * @ORM\Column(type="string", length=255, unique=true)
     */
    private $code;

    /**
     * @ORM\Column(type="string", length=255)
     */
    private $type;

    /**
     * @ORM\OneToMany(targetEntity="App\Entity\WebsiteBoolean", mappedBy="eavAttribute", cascade={"remove"})
     */
    private $websiteBooleans;

    /**
     * @ORM\OneToMany(targetEntity="App\Entity\WebsiteDatetime", mappedBy="eavAttribute", cascade={"remove"})
     */
    private $websiteDatetimes;

    /**
     * @ORM\OneToMany(targetEntity="App\Entity\WebsiteFloat", mappedBy="eavAttribute", cascade={"remove"})
     */
    private $websiteFloats;

    /**
     * @ORM\OneToMany(targetEntity="App\Entity\WebsiteInteger", mappedBy="eavAttribute", cascade={"remove"})
     */
    private $websiteIntegers;

    /**
     * @ORM\OneToMany(targetEntity="App\Entity\WebsiteString", mappedBy="eavAttribute", cascade={"remove"})
     */
    private $websiteStrings;

    /**
     * @ORM\OneToMany(targetEntity="App\Entity\WebsiteText", mappedBy="eavAttribute", cascade={"remove"})
     */
    private $websiteTexts;

    public function __construct()
    {
        $this->websiteBooleans = new ArrayCollection();
        $this->websiteDatetimes = new ArrayCollection();
        $this->websiteFloats = new ArrayCollection();
        $this->websiteIntegers = new ArrayCollection();
        $this->websiteStrings = new ArrayCollection();
        $this->websiteTexts = new ArrayCollection();
    }

    public function __toString()
    {
        return $this->code;
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getCode(): ?string
    {
        return $this->code;
    }

    public function setCode(string $code): self
    {
        $this->code = $code;

        return $this;
    }

    public function getDescription(): ?string
    {
        return $this->description;
    }

    public function setDescription(string $description): self
    {
        $this->description = $description;

        return $this;
    }

    public function getType(): ?string
    {
        return $this->type;
    }

    public function setType(string $type): self
    {
        $this->type = $type;

        return $this;
    }

    /**
     * @return Collection|WebsiteBoolean[]
     */
    public function getWebsiteBooleans(): Collection
    {
        return $this->websiteBooleans;
    }

    public function addWebsiteBoolean(WebsiteBoolean $websiteBoolean): self
    {
        if (!$this->websiteBooleans->contains($websiteBoolean)) {
            $this->websiteBooleans[] = $websiteBoolean;
            $websiteBoolean->setEavAttribute($this);
        }

        return $this;
    }

    public function removeWebsiteBoolean(WebsiteBoolean $websiteBoolean): self
    {
        if ($this->websiteBooleans->contains($websiteBoolean)) {
            $this->websiteBooleans->removeElement($websiteBoolean);
            // set the owning side to null (unless already changed)
            if ($websiteBoolean->getEavAttribute() === $this) {
                $websiteBoolean->setEavAttribute(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|WebsiteDatetime[]
     */
    public function getWebsiteDatetimes(): Collection
    {
        return $this->websiteDatetimes;
    }

    public function addWebsiteDatetime(WebsiteDatetime $websiteDatetime): self
    {
        if (!$this->websiteDatetimes->contains($websiteDatetime)) {
            $this->websiteDatetimes[] = $websiteDatetime;
            $websiteDatetime->setEavAttribute($this);
        }

        return $this;
    }

    public function removeWebsiteDatetime(WebsiteDatetime $websiteDatetime): self
    {
        if ($this->websiteDatetimes->contains($websiteDatetime)) {
            $this->websiteDatetimes->removeElement($websiteDatetime);
            // set the owning side to null (unless already changed)
            if ($websiteDatetime->getEavAttribute() === $this) {
                $websiteDatetime->setEavAttribute(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|WebsiteFloat[]
     */
    public function getWebsiteFloats(): Collection
    {
        return $this->websiteFloats;
    }

    public function addWebsiteFloat(WebsiteFloat $websiteFloat): self
    {
        if (!$this->websiteFloats->contains($websiteFloat)) {
            $this->websiteFloats[] = $websiteFloat;
            $websiteFloat->setEavAttribute($this);
        }

        return $this;
    }

    public function removeWebsiteFloat(WebsiteFloat $websiteFloat): self
    {
        if ($this->websiteFloats->contains($websiteFloat)) {
            $this->websiteFloats->removeElement($websiteFloat);
            // set the owning side to null (unless already changed)
            if ($websiteFloat->getEavAttribute() === $this) {
                $websiteFloat->setEavAttribute(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|WebsiteInteger[]
     */
    public function getWebsiteIntegers(): Collection
    {
        return $this->websiteIntegers;
    }

    public function addWebsiteInteger(WebsiteInteger $websiteInteger): self
    {
        if (!$this->websiteIntegers->contains($websiteInteger)) {
            $this->websiteIntegers[] = $websiteInteger;
            $websiteInteger->setEavAttribute($this);
        }

        return $this;
    }

    public function removeWebsiteInteger(WebsiteInteger $websiteInteger): self
    {
        if ($this->websiteIntegers->contains($websiteInteger)) {
            $this->websiteIntegers->removeElement($websiteInteger);
            // set the owning side to null (unless already changed)
            if ($websiteInteger->getEavAttribute() === $this) {
                $websiteInteger->setEavAttribute(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|WebsiteString[]
     */
    public function getWebsiteStrings(): Collection
    {
        return $this->websiteStrings;
    }

    public function addWebsiteString(WebsiteString $websiteString): self
    {
        if (!$this->websiteStrings->contains($websiteString)) {
            $this->websiteStrings[] = $websiteString;
            $websiteString->setEavAttribute($this);
        }

        return $this;
    }

    public function removeWebsiteString(WebsiteString $websiteString): self
    {
        if ($this->websiteStrings->contains($websiteString)) {
            $this->websiteStrings->removeElement($websiteString);
            // set the owning side to null (unless already changed)
            if ($websiteString->getEavAttribute() === $this) {
                $websiteString->setEavAttribute(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|WebsiteText[]
     */
    public function getWebsiteTexts(): Collection
    {
        return $this->websiteTexts;
    }

    public function addWebsiteText(WebsiteText $websiteText): self
    {
        if (!$this->websiteTexts->contains($websiteText)) {
            $this->websiteTexts[] = $websiteText;
            $websiteText->setEavAttribute($this);
        }

        return $this;
    }

    public function removeWebsiteText(WebsiteText $websiteText): self
    {
        if ($this->websiteTexts->contains($websiteText)) {
            $this->websiteTexts->removeElement($websiteText);
            // set the owning side to null (unless already changed)
            if ($websiteText->getEavAttribute() === $this) {
                $websiteText->setEavAttribute(null);
            }
        }

        return $this;
    }
}
