<?php

namespace App\Entity;

use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;

/**
 * @ORM\Entity(repositoryClass="App\Repository\WebsiteEntityRepository")
 */
class WebsiteEntity
{
    /**
     * @ORM\Id()
     * @ORM\GeneratedValue()
     * @ORM\Column(type="integer")
     */
    private $id;

    /**
     * @ORM\Column(type="string", length=255)
     */
    private $domain;

    /**
     * @ORM\Column(type="boolean")
     */
    private $https;

    /**
     * @ORM\OneToMany(targetEntity="App\Entity\WebsiteString",
     * mappedBy="websiteEntity",
     * cascade={"persist","remove"})
     */
    private $strings;

    /**
     * @ORM\OneToMany(targetEntity="App\Entity\WebsiteText",
     * mappedBy="websiteEntity",
     * cascade={"persist","remove"})
     */
    private $texts;

    /**
     * @ORM\OneToMany(targetEntity="App\Entity\WebsiteBoolean",
     * mappedBy="websiteEntity",
     * cascade={"persist","remove"})
     */
    private $booleans;

    /**
     * @ORM\OneToMany(targetEntity="App\Entity\WebsiteInteger",
     * mappedBy="websiteEntity",
     * cascade={"persist","remove"})
     */
    private $integers;

    /**
     * @ORM\OneToMany(targetEntity="App\Entity\WebsiteFloat",
     * mappedBy="websiteEntity",
     * cascade={"persist","remove"})
     */
    private $floats;

    /**
     * @ORM\OneToMany(targetEntity="App\Entity\WebsiteDatetime",
     * mappedBy="websiteEntity",
     * cascade={"persist","remove"})
     */
    private $datetimes;

    public function __construct()
    {
        $this->strings = new ArrayCollection();
        $this->texts = new ArrayCollection();
        $this->booleans = new ArrayCollection();
        $this->integers = new ArrayCollection();
        $this->floats = new ArrayCollection();
        $this->datetimes = new ArrayCollection();
    }

    public function __toString()
    {
        return $this->domain;
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getDomain(): ?string
    {
        return $this->domain;
    }

    public function setDomain(string $domain): self
    {
        $this->domain = $domain;

        return $this;
    }

    public function getHttps(): ?bool
    {
        return $this->https;
    }

    public function setHttps(bool $https): self
    {
        $this->https = $https;

        return $this;
    }

    /**
     * @return Collection|self[]
     */
    public function getStrings(): Collection
    {
        return $this->strings;
    }

    public function addString(WebsiteString $string): self
    {
        if (!$this->strings->contains($string)) {
            $this->strings[] = $string;
            $string->setWebsiteEntity($this);
        }

        return $this;
    }

    public function removeString(WebsiteString $string): self
    {
        if ($this->strings->contains($string)) {
            $this->strings->removeElement($string);
            // set the owning side to null (unless already changed)
            if ($string->getWebsiteEntity() === $this) {
                $string->setWebsiteEntity(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|WebsiteText[]
     */
    public function getTexts(): Collection
    {
        return $this->texts;
    }

    public function addText(WebsiteText $text): self
    {
        if (!$this->texts->contains($text)) {
            $this->texts[] = $text;
            $text->setWebsiteEntity($this);
        }

        return $this;
    }

    public function removeText(WebsiteText $text): self
    {
        if ($this->texts->contains($text)) {
            $this->texts->removeElement($text);
            // set the owning side to null (unless already changed)
            if ($text->getWebsiteEntity() === $this) {
                $text->setWebsiteEntity(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|WebsiteBoolean[]
     */
    public function getBooleans(): Collection
    {
        return $this->booleans;
    }

    public function addBoolean(WebsiteBoolean $boolean): self
    {
        if (!$this->booleans->contains($boolean)) {
            $this->booleans[] = $boolean;
            $boolean->setWebsiteEntity($this);
        }

        return $this;
    }

    public function removeBoolean(WebsiteBoolean $boolean): self
    {
        if ($this->booleans->contains($boolean)) {
            $this->booleans->removeElement($boolean);
            // set the owning side to null (unless already changed)
            if ($boolean->getWebsiteEntity() === $this) {
                $boolean->setWebsiteEntity(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|WebsiteInteger[]
     */
    public function getIntegers(): Collection
    {
        return $this->integers;
    }

    public function addInteger(WebsiteInteger $integer): self
    {
        if (!$this->integers->contains($integer)) {
            $this->integers[] = $integer;
            $integer->setWebsiteEntity($this);
        }

        return $this;
    }

    public function removeInteger(WebsiteInteger $integer): self
    {
        if ($this->integers->contains($integer)) {
            $this->integers->removeElement($integer);
            // set the owning side to null (unless already changed)
            if ($integer->getWebsiteEntity() === $this) {
                $integer->setWebsiteEntity(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|WebsiteFloat[]
     */
    public function getFloats(): Collection
    {
        return $this->floats;
    }

    public function addFloat(WebsiteFloat $float): self
    {
        if (!$this->floats->contains($float)) {
            $this->floats[] = $float;
            $float->setWebsiteEntity($this);
        }

        return $this;
    }

    public function removeFloat(WebsiteFloat $float): self
    {
        if ($this->floats->contains($float)) {
            $this->floats->removeElement($float);
            // set the owning side to null (unless already changed)
            if ($float->getWebsiteEntity() === $this) {
                $float->setWebsiteEntity(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|WebsiteDatetime[]
     */
    public function getDatetimes(): Collection
    {
        return $this->datetimes;
    }

    public function addDatetime(WebsiteDatetime $datetime): self
    {
        if (!$this->datetimes->contains($datetime)) {
            $this->datetimes[] = $datetime;
            $datetime->setWebsiteEntity($this);
        }

        return $this;
    }

    public function removeDatetime(WebsiteDatetime $datetime): self
    {
        if ($this->datetimes->contains($datetime)) {
            $this->datetimes->removeElement($datetime);
            // set the owning side to null (unless already changed)
            if ($datetime->getWebsiteEntity() === $this) {
                $datetime->setWebsiteEntity(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|self[]
     */
    public function getWebsiteEntitys(): Collection
    {
        return $this->websiteEntitys;
    }

    public function addWebsiteEntity(self $websiteEntity): self
    {
        if (!$this->websiteEntitys->contains($websiteEntity)) {
            $this->websiteEntitys[] = $websiteEntity;
            $websiteEntity->addEavAttribute($this);
        }

        return $this;
    }

    public function removeWebsiteEntity(self $websiteEntity): self
    {
        if ($this->websiteEntitys->contains($websiteEntity)) {
            $this->websiteEntitys->removeElement($websiteEntity);
            $websiteEntity->removeEavAttribute($this);
        }

        return $this;
    }
}
