<?php

namespace App\Form;

use App\Entity\WebsiteEntity;
use App\Service\WebsiteManager;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Doctrine\Common\Persistence\ObjectManager;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\Extension\Core\Type\TextareaType;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\Extension\Core\Type\IntegerType;
use Symfony\Component\Form\Extension\Core\Type\NumberType;
use Symfony\Component\Form\Extension\Core\Type\DateTimeType;

class WebsiteEntityType extends AbstractType
{
    private $entityManager;
    private $websiteManager;

    public function __construct(ObjectManager $entityManager, WebsiteManager $websiteManager)
    {
        $this->entityManager = $entityManager;
        $this->websiteManager = $websiteManager;
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('domain')
            ->add('https')
        ;

        $entity = $builder->getData();

        $eavAttributes = $this->entityManager->getRepository(\App\Entity\EavAttribute::class)->findAll();
        foreach ($eavAttributes as $eavAttribute) {
            switch ($eavAttribute->getType()) {
                case 'string':
                    $builder->add(
                        $eavAttribute->getCode(),
                        TextType::class,
                        [
                            'mapped' => false,
                            'required' => false,
                            'data' => $this->websiteManager->getEavValue($entity, $eavAttribute->getCode())
                        ]
                    );
                    break;
                case 'text':
                    $builder->add(
                        $eavAttribute->getCode(),
                        TextareaType::class,
                        [
                            'mapped' => false,
                            'required' => false,
                            'data' => $this->websiteManager->getEavValue($entity, $eavAttribute->getCode())
                        ]
                    );
                    break;
                case 'boolean':
                    $builder->add(
                        $eavAttribute->getCode(),
                        CheckboxType::class,
                        [
                            'mapped' => false,
                            'required' => false,
                            'data' => $this->websiteManager->getEavValue($entity, $eavAttribute->getCode())
                        ]
                    );
                    break;
                case 'integer':
                    $builder->add(
                        $eavAttribute->getCode(),
                        IntegerType::class,
                        [
                            'mapped' => false,
                            'required' => false,
                            'data' => $this->websiteManager->getEavValue($entity, $eavAttribute->getCode())
                        ]
                    );
                    break;
                case 'float':
                    $builder->add(
                        $eavAttribute->getCode(),
                        NumberType::class,
                        [
                            'mapped' => false,
                            'required' => false,
                            'data' => $this->websiteManager->getEavValue($entity, $eavAttribute->getCode())
                        ]
                    );
                    break;
                case 'datetime':
                    $builder->add(
                        $eavAttribute->getCode(),
                        DateTimeType::class,
                        [
                            'mapped' => false,
                            'required' => false,
                            'data' => $this->websiteManager->getEavValue($entity, $eavAttribute->getCode())
                        ]
                    );
                    break;
                /*default:
                    $builder->add(
                        $eavAttribute->getCode(),
                        null,
                        [
                            'mapped' => false,
                            'requirequired' => false,
                            'data' => $this->websiteManager->getEavValue($entity, $eavAttribute->getCode())
                        ]
                    );
                    break;*/
            }

        }
    }

    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefaults([
            'data_class' => WebsiteEntity::class,
        ]);
    }
}
